﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.IO;
using HeuristicLab.Hive.Contracts.BusinessObjects;

namespace HeuristicLab.Hive.Server.DataAccess {
  public interface IJobDao: IGenericDao<JobDto> {
    IEnumerable<JobDto> FindActiveJobsOfSlave(SlaveDto slave);

    IEnumerable<JobDto> GetJobsByState(JobState state);

    void AssignSlaveToJob(Guid slaveId, Guid jobId);

    void UnAssignSlaveToJob(Guid jobId);

    void SetJobOffline(JobDto job);

    SerializedJob InsertWithAttachedJob(SerializedJob job);

    byte[] GetBinaryJobFile(Guid jobId); 

    IEnumerable<JobDto> FindFittingJobs(JobState state, int freeCores, int freeMemory, Guid slaveGuid);

    Stream GetSerializedJobStream(Guid jobId);

    IEnumerable<JobDto> FindWithLimitations(JobState jobState, int offset, int count);

    void SetBinaryJobFile(Guid jobId, byte[] data);

    IEnumerable<JobDto> FindJobsById(IEnumerable<Guid> jobIds);

    bool IsUserAuthorizedForJobs(Guid userId, params Guid[] jobIds);

    IEnumerable<JobDto> FindJobsByParentId(Guid? parentJobId, bool recursive);

    /// <summary>
    /// Returns a list of jobs which are on state WaitForChildJobs and those child-jobs are finished
    /// </summary>
    IEnumerable<JobDto> FindJobsWithFinishedChilds(Guid guid);
  }
}
